@@ -6,7 +6,7 @@
 #
 
 # Top-level keepaway directory  **SET THIS OPTION**
-keepaway_dir=/home/kuhlmann/keepaway-0.2
+keepaway_dir=/home/kuhlmann/keepaway-0.3
 
 ############################################################
 # Keeper options                                           #
@@ -63,6 +63,8 @@ save_rcl_log=0
 log_dir=$keepaway_dir/logs
 
 port=5800
+coach_port=$[port + 1]
+olcoach_port=$[port + 2]
 sleep_time=8
 
 ############################################################
@@ -90,7 +92,7 @@ if (( $unrestricted_vision )); then
   vision_opts="$s::visible_angle=360"
 fi
 
-server_opts="$s::port=$port $s::half_time=-1 $s::forbid_kick_off_offside=0 $s::use_offside=0 $s::stamina_inc_max=3500 $s::synch_mode=$synch_mode $keepaway_opts $log_opts $vision_opts"
+server_opts="$s::port=$port $s::coach_port=$coach_port $s::olcoach_port=$olcoach_port $s::half_time=-1 $s::forbid_kick_off_offside=0 $s::use_offside=0 $s::stamina_inc_max=3500 $s::synch_mode=$synch_mode $keepaway_opts $log_opts $vision_opts"
 
 keeper_opts="-t keepers -e $keeper_learn -q $keeper_policy"
 taker_opts="-t takers -e $taker_learn -q $taker_policy"
