@@ -2260,175 +2260,6 @@ void WorldModel::logObjectInformation( int iLogLevel, ObjectT obj )
       Log.log( iLogLevel, str );
 }
 
-/*! This method logs drawing information to the log file LogDraw. The drawing
-    information is written in the syntax that is understood by the soccer
-    monitor. The contents of the created file can afterwards be read by an
-    (adapted) logplayer to show the logged information. The information logged
-    in this method is all the global position information of the players on the
-    field.
-    \param iLogLevel loglevel that has to be passed to the Logger.
-*/
-void WorldModel::logDrawInfo()
-{
-  //gjk
-//   if( getCurrentCycle() % ( SS->getHalfTime() * SS->getSimulatorStep()) == 0 )
-//     return ;
-
-//   bool   bReturn1 = false, bReturn2 = false;
-//   double dConfThr = PS->getPlayerConfThr();
-//   int    iIndex;
-//   char   strMsg1[MAX_MSG], strMsg2[MAX_MSG];
-//   char   strColorLeft[]  = "ffff00" ;
-//   char   strColorRight[] = "0000ff" ;
-//   if( getSide() != SIDE_LEFT )
-//   {
-//     sprintf( strColorLeft, strColorRight );
-//     sprintf( strColorRight, "ffff00" );
-//   }
-
-
-//   sprintf( strMsg1, "_2D_ CIRCLE col=%s ", strColorLeft ) ;
-//   // first each players logs the positions of all the teammates
-//   for( ObjectT o = iterateObjectStart( iIndex, OBJECT_SET_TEAMMATES, dConfThr );
-//        o != OBJECT_ILLEGAL;
-//        o = iterateObjectNext ( iIndex, OBJECT_SET_TEAMMATES, dConfThr ) )
-//   {
-//      bReturn1 = true;
-
-//      // add all the global positions to the string
-//      sprintf( &strMsg1[strlen(strMsg1)], "(%1.2f,%1.2f,1.3) ",
-//       m_iMultX*getGlobalPosition( o ).getX(),
-//       m_iMultY*getGlobalPosition( o ).getY() );
-//   }
-//   iterateObjectDone( iIndex );
-
-//   if( bReturn1 == false )
-//     sprintf( strMsg1, "_2D_ " );
-//   else
-//     strcat( strMsg1, "; " );
-
-//   sprintf( strMsg2, "CIRCLE col=%s ", strColorRight ) ;
-//   for( ObjectT o = iterateObjectStart( iIndex, OBJECT_SET_OPPONENTS, dConfThr);
-//        o != OBJECT_ILLEGAL;
-//        o = iterateObjectNext ( iIndex, OBJECT_SET_OPPONENTS, dConfThr ) )
-//   {
-//      bReturn2 = true;
-
-//      // add all the global positions to the string
-//      sprintf( &strMsg2[strlen(strMsg2)], "(%1.2f,%1.2f,1.3) ",
-//       m_iMultX*getGlobalPosition( o ).getX(),
-//       m_iMultY*getGlobalPosition( o ).getY() );
-//   }
-//   iterateObjectDone( iIndex );
-//   strcat( strMsg2, ";" );
-
-//   if( bReturn2 == true )
-//     strcat( strMsg1, strMsg2 );
-//   if( bReturn1 == true || bReturn2 == true)
-//     LogDraw.log( iLogLevel, strMsg1 );
-
-//   return ;
-}
-
-/*! This method logs drawing information to the log file LogDraw. The drawing
-    information is written in the syntax that is understood by the soccer
-    monitor. The contents of the created file can afterwards be read by an
-    (adapted) logplayer to show the logged information. This method logs all
-    the information about the coordination graphs.
-    \param iLogLevel loglevel that has to be passed to the Logger.
-*/
-void WorldModel::logCoordInfo()
-{
-  //gjk
-//   if( getCurrentCycle() % ( SS->getHalfTime() * SS->getSimulatorStep()) == 0 )
-//     return ;
-
-//   bool   bReturn = false;
-//   int    iIndex;
-//   double dConfThr = PS->getPlayerConfThr();
-//   char   strMsg[MAX_MSG];
-
-//   map<double, ObjectT > mapDistToBall;
-//   VecPosition posBall = getGlobalPosition( OBJECT_BALL ), posFirst;
-//   int i = 0;
-
-//   for( ObjectT o = iterateObjectStart( iIndex, OBJECT_SET_TEAMMATES, dConfThr);
-//        o != OBJECT_ILLEGAL;
-//        o = iterateObjectNext ( iIndex, OBJECT_SET_TEAMMATES, dConfThr ) )
-//   {
-//      // add all the global positions to the string
-//      mapDistToBall.insert(
-//        make_pair( getGlobalPosition( o ).getDistanceTo( posBall ), o ) );
-//   }
-//   iterateObjectDone( iIndex );
-
-//   sprintf( strMsg, "all_2D_ ");
-//   for(  map<double, ObjectT >::iterator iter = mapDistToBall.begin();
-//         iter != mapDistToBall.end()  ;
-//         iter ++ )
-//   {
-//     if( i == 0 )
-//       posFirst = getGlobalPosition( iter->second );
-//     else if( iter->second == getAgentObjectType() && i < 4 &&
-//              iter->first < 20.0 )
-//     {
-//       bReturn = true;
-//       sprintf( &strMsg[strlen(strMsg)],
-//                        "LINE col=%s (%1.2f,%1.2f,%1.2f,%1.2f);",
-//         m_colorPlayers[ SoccerTypes::getIndex( getAgentObjectType() ) ],
-//         m_iMultX*posFirst.getX(),
-//         m_iMultY*posFirst.getY(),
-//         m_iMultX*getGlobalPosition( iter->second ).getX(),
-//         m_iMultY*getGlobalPosition( iter->second ).getY() );
-//     }
-
-//     i++;
-//   }
-
-//   if( bReturn == true )
-//     LogDraw.log( iLogLevel, strMsg );
-}
-
-
-
-/* This method logs the ball position and its velocity.
-
-   \param iLogLevel log level to which the ball information should be
-   printed.*/
-bool WorldModel::logDrawBallInfo()
-{
-  //gjk
-//   int  iPoints = 20;
-//   char strMsg[MAX_MSG];
-//   char *strColor = "ff0000";
-
-//   VecPosition vel     = getGlobalVelocity( OBJECT_BALL );
-//   VecPosition pos     = getBallPos(), pos1, pos2;
-//   AngDeg      angOrth = VecPosition::normalizeAngle( vel.getDirection( )+90 );
-//   VecPosition posBall = getBallPos();
-//   sprintf( strMsg, "_2D_ CIRCLE col=%s (%1.2f,%1.2f,0.3) ; ",
-//      strColor, m_iMultX*posBall.getX(), m_iMultY*posBall.getY() );
-     
-//   for( int i = 0; i < iPoints; i ++ )
-//   {
-//     // create all the orthogonal lines
-//     pos += vel;
-//     pos1 = pos + VecPosition( -0.5*vel.getMagnitude(), angOrth, POLAR );
-//     pos2 = pos + VecPosition(  0.5*vel.getMagnitude(), angOrth, POLAR );
-//     sprintf( &strMsg[strlen(strMsg)], "LINE col=%s (%1.2f,%1.2f,%1.2f,%1.2f);",
-//             strColor, m_iMultX*pos1.getX(), m_iMultY*pos1.getY(),
-//             m_iMultX*pos2.getX(), m_iMultY*pos2.getY() );
-//     vel *= SS->getBallDecay();
-//   }
-  
-//   // finally create the line through all orthogonal lines
-//   sprintf( &strMsg[strlen(strMsg)], "LINE col=%s (%1.2f,%1.2f,%1.2f,%1.2f) ;",
-//           strColor, m_iMultX*getBallPos().getX(), m_iMultY*getBallPos().getY(),
-//           m_iMultX*pos.getX(), m_iMultY*pos.getY() );
-
-//   return LogDraw.log( iLogLevel, strMsg );
-  return true;
-}
 
 /*! This method checks whether the feature of type 'type' is relevant. This is
     done by comparing the time of the feature with the current time. When it
