@@ -879,9 +879,6 @@ public:
 
   double        keeperReward               (                                 );
   int           keeperStateVars            ( double         state[]          );
-  int           keeperTileWidths           ( double         tileWidths[],
-					     int            numK,
-					     int            numT             );
 
   ////////////////////////// VARIOUS (WorldModel.cc) ///////////////////////////
 
@@ -905,9 +902,6 @@ public:
   // methods that deal with debugging
   void          logObjectInformation       ( int            iLogLevel,
                                              ObjectT        o                );
-  void          logDrawInfo                (                                 );
-  void          logCoordInfo               (                                 );
-  bool          logDrawBallInfo            (                                 );
   
   // specific static variables
   int m_iMultX;                     /*!< This variable denotes with which value
